pub struct EngramHash {
pub layer_ids: Vec<usize>,
pub max_ngram: usize,
pub n_heads: usize,
pub compressed_vocab: usize,
pub pad_id: i64,
pub primes: Vec<Vec<Vec<u64>>>,
pub offsets: Vec<Vec<u64>>,
pub token_map: Vec<u32>,
pub multipliers: Vec<[u64; 4]>,
/* private fields */
}Expand description
The exact source layout of the V4.1 n-gram tables. The two configured Engram layers have disjoint prime ranges, even though both tables use the same nominal 16M vocabulary.
Fields
layer_ids: Vec<usize>max_ngram: usizen_heads: usizecompressed_vocab: usizepad_id: i64primes: Vec<Vec<Vec<u64>>>offsets: Vec<Vec<u64>>token_map: Vec<u32>multipliers: Vec<[u64; 4]>Implementations