matvec_class

Function matvec_class 

pub fn matvec_class(rows: usize, cols: usize) -> OpClass
Which probe a large matvec belongs to. The head is an order of magnitude bigger than anything else that reaches this gate, and the two populations do not have the same answer.