pub struct QwenImageChainArgs<'a> {
pub image: &'a mut [f32],
pub text: &'a mut [f32],
pub image_tokens: usize,
pub text_tokens: usize,
pub heads: usize,
pub head_dim: usize,
pub image_cos: &'a [f32],
pub image_sin: &'a [f32],
pub text_cos: &'a [f32],
pub text_sin: &'a [f32],
pub blocks: &'a [QwenImageChainBlock<'a>],
}Expand description
Explicit whole-forward Qwen state contract. The WGPU backend uploads the
two initial streams once, encodes a bounded number of complete blocks per
submission, and reads the final state once. blocks is immutable for the
call, while the two stream slices receive only the final readback.
Fields
image: &'a mut [f32]text: &'a mut [f32]image_tokens: usizetext_tokens: usizeheads: usizehead_dim: usizeimage_cos: &'a [f32]image_sin: &'a [f32]text_cos: &'a [f32]text_sin: &'a [f32]blocks: &'a [QwenImageChainBlock<'a>]Auto Trait Implementations
impl<'a> !UnwindSafe for QwenImageChainArgs<'a>
impl<'a> Freeze for QwenImageChainArgs<'a>
impl<'a> RefUnwindSafe for QwenImageChainArgs<'a>
impl<'a> Send for QwenImageChainArgs<'a>
impl<'a> Sync for QwenImageChainArgs<'a>
impl<'a> Unpin for QwenImageChainArgs<'a>
impl<'a> UnsafeUnpin for QwenImageChainArgs<'a>